asr.defectformation
===================

.. automodule:: asr.defectformation

   
   
   .. rubric:: Functions

   
   .. autofunction:: check_and_get_general_inputs
   .. autofunction:: collect_data
   .. autofunction:: find_file_in_folder
   .. autofunction:: intersection
   .. autofunction:: line
   .. autofunction:: line_intersection
   .. autofunction:: plot_formation_and_transitions
   
   

   
   
   

   
   
   